@@ -4,7 +4,7 @@ package JSON::Schema::Draft201909::Result;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains the result of a JSON Schema evaluation
 
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -146,7 +146,7 @@ sub TO_JSON {
 sub _map_uris {
   my $data = shift;
   return +{
-    $data->%*,
+    %$data,
     map +($_ => Mojo::URL->new->fragment($data->{$_})->to_string),
       qw(instanceLocation keywordLocation),
   };
@@ -166,7 +166,7 @@ JSON::Schema::Draft201909::Result - Contains the result of a JSON Schema evaluat
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
